@@ -7,7 +7,7 @@ use Storable;
 use Text::VisualWidth::PP 0.03 qw(vwidth);
 use Term::ReadKey qw(GetTerminalSize ReadLine);
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 our @EXPORT = qw( caroline );
 
@@ -15,7 +15,7 @@ my $HISTORY_NEXT = 0;
 my $HISTORY_PREV = 1;
 
 use Class::Accessor::Lite 0.05 (
-    rw => [qw(completion_callback)],
+    rw => [qw(completion_callback history_max_len)],
 );
 
 sub new {
@@ -25,6 +25,7 @@ sub new {
         history => [],
         debug => !!$ENV{CAROLINE_DEBUG},
         multi_line => 1,
+        history_max_len => 100,
         %args
     }, $class;
     return $self;
@@ -127,6 +128,9 @@ sub disable_raw_mode {
 
 sub history_add {
     my ($self, $line) = @_;
+    if (@{$self->{history}}+1 > $self->history_max_len) {
+        shift @{$self->{history}};
+    }
     push @{$self->{history}}, $line;
 }
 
@@ -578,9 +582,9 @@ Options are:
 
 =over 4
 
-=item history : ArrayRef[Str]
+=item history_max_len : Str
 
-You can pass the older history data for constructor.
+Set the limitation for max history size.
 
 =item completion_callback : CodeRef
 
@@ -611,6 +615,10 @@ Read line with C<$prompt>.
 
 Trailing newline is removed. Returns undef on EOF.
 
+=item $caroline->history_add($line)
+
+Add $line to the history.
+
 =item $caroline->history()
 
 Get the current history data in C< ArrayRef[Str] >.
